==> plopp-24.1.0.tar.gz: plopp-24.1.0/docs/user-guide/index.md <==
# User guide

## Getting started


::::{grid} 3

:::{grid-item-card} Installation
:link: getting-started/installation.md

:::

:::{grid-item-card} Overview
:link: getting-started/overview.ipynb

:::

:::{grid-item-card} Numpy, Pandas, and Xarray
:link: getting-started/numpy-pandas-xarray.ipynb

:::

::::


```{toctree}
---
hidden:
---

getting-started/installation
getting-started/overview
getting-started/numpy-pandas-xarray
```

## Plot Types

::::{grid} 3

:::{grid-item-card} Line plot
:link: plot-types/line-plot.ipynb
:img-bottom: ../_static/plot-types/line-plot.png

:::

:::{grid-item-card} Image plot
:link: plot-types/image-plot.ipynb
:img-bottom: ../_static/plot-types/image-plot.png

:::

::::{grid-item-card} Slicer plot
:link: plot-types/slicer-plot.ipynb
:img-bottom: ../_static/plot-types/slicer-plot.png

:::

::::

::::{grid} 3

:::{grid-item-card} Inspector plot
:link: plot-types/inspector-plot.ipynb
:img-bottom: ../_static/plot-types/inspector-plot.png

:::

:::{grid-item-card} Super-plot
:link: plot-types/super-plot.ipynb
:img-bottom: ../_static/plot-types/super-plot.png

:::

:::{grid-item-card} Scatter 3D plot
:link: plot-types/scatter3d-plot.ipynb
:img-bottom: ../_static/plot-types/scatter3d-plot.png

:::

::::

::::{grid} 3

:::{grid-item-card} {octicon}`download;1em` Saving figures to disk
:link: plot-types/saving-figures.ipynb

:::

::::

```{toctree}
---
hidden:
---

plot-types/line-plot
plot-types/image-plot
plot-types/slicer-plot
plot-types/inspector-plot
plot-types/super-plot
plot-types/scatter3d-plot
plot-types/saving-figures
```

## Custom figures

::::{grid} 3

:::{grid-item-card} Subplots / Tiled plots
:link: customization/subplots.ipynb
:img-bottom: ../_static/customization/subplots.png

:::

:::{grid-item-card} Tweaking figures
:link: customization/tweaking-figures.ipynb
:img-bottom: ../_static/customization/tweaking-figures.png

:::

::::{grid-item-card} Building custom interfaces
:link: customization/custom-interfaces.ipynb
:img-bottom: ../_static/customization/custom-interfaces.png

:::

::::

::::{grid} 3

:::{grid-item-card} Graph and node tips
:link: customization/graph-node-tips.ipynb
:img-bottom: ../_static/customization/graph-node-tips.png

:::

::::

```{toctree}
---
hidden:
---

customization/subplots
customization/tweaking-figures
customization/custom-interfaces
customization/graph-node-tips
```

==> plopp-24.2.0.tar.gz: plopp-24.2.0/docs/user-guide/index.md <==
# User guide

## Getting started

::::{grid} 3

:::{grid-item-card} {octicon}`desktop-download;1em`&nbsp; Installation
:link: getting-started/installation.md

:::

:::{grid-item-card} {octicon}`eye;1em`&nbsp; Overview
:link: getting-started/overview.ipynb

:::

:::{grid-item-card} {octicon}`graph;1em`&nbsp; Numpy, Pandas, and Xarray
:link: getting-started/numpy-pandas-xarray.ipynb

:::

::::

::::{grid} 3

:::{grid-item-card} {octicon}`download;1em`&nbsp; Saving figures to disk
:link: plot-types/saving-figures.ipynb

:::

::::

```{toctree}
---
hidden:
---

getting-started/installation
getting-started/overview
getting-started/numpy-pandas-xarray
getting-started/saving-figures
```

## Plot Types

::::{grid} 3

:::{grid-item-card} Line plot
:link: plot-types/line-plot.ipynb
:img-bottom: ../_static/plot-types/line-plot.png

:::

:::{grid-item-card} Image plot
:link: plot-types/image-plot.ipynb
:img-bottom: ../_static/plot-types/image-plot.png

:::

::::{grid-item-card} Slicer plot
:link: plot-types/slicer-plot.ipynb
:img-bottom: ../_static/plot-types/slicer-plot.png

:::

::::

::::{grid} 3

:::{grid-item-card} Inspector plot
:link: plot-types/inspector-plot.ipynb
:img-bottom: ../_static/plot-types/inspector-plot.png

:::

:::{grid-item-card} Super-plot
:link: plot-types/super-plot.ipynb
:img-bottom: ../_static/plot-types/super-plot.png

:::

:::{grid-item-card} Scatter 3D plot
:link: plot-types/scatter3d-plot.ipynb
:img-bottom: ../_static/plot-types/scatter3d-plot.png

:::

::::

```{toctree}
---
hidden:
---

plot-types/line-plot
plot-types/image-plot
plot-types/slicer-plot
plot-types/inspector-plot
plot-types/super-plot
plot-types/scatter3d-plot
```

## Custom figures

::::{grid} 3

:::{grid-item-card} Subplots / Tiled plots
:link: customization/subplots.ipynb
:img-bottom: ../_static/customization/subplots.png

:::

:::{grid-item-card} Tweaking figures
:link: customization/tweaking-figures.ipynb
:img-bottom: ../_static/customization/tweaking-figures.png

:::

::::{grid-item-card} Building custom interfaces
:link: customization/custom-interfaces.ipynb
:img-bottom: ../_static/customization/custom-interfaces.png

:::

::::

::::{grid} 3

:::{grid-item-card} Graph and node tips
:link: customization/graph-node-tips.ipynb
:img-bottom: ../_static/customization/graph-node-tips.png

:::

::::

```{toctree}
---
hidden:
---

customization/subplots
customization/tweaking-figures
customization/custom-interfaces
customization/graph-node-tips
```
